{
  "name": "FaSpell",
  "version": "1.0.0",
  "task": "Spell-Checking",
  "splits": ["main", "ocr"],
  "description": "FASpell dataset was developed for the evaluation of spell checking algorithms. It contains a set of pairs of misspelled Persian words and their corresponding corrected forms similar to the ASpell dataset used for English.",
  "size": {"main": 5062, "ocr":  800},
  "filenames": ["faspell_main.txt", "faspell_ocr.txt"]
}
